local media = LibStub("LibSharedMedia-2.0")
local L = LibStub("AceLocale-3.0"):GetLocale("Yikes")

local defaults = {
	profile = {
		afkMessage = "",
		backMessage = "",
		alertPartyRaid = false,
		font = "Friz Quadrata TT",
		fontSize = 10,
		fade = false,
		fadeDuration = 30,
		mute = true,
		bgColour = {r=1, g=1, b=1, a=1},
		textColour = {r=0, g=0, b=0, a=1},
		channels = {},
	},
}

function Yikes:GetDefaultConfig()
	return defaults
end

local function getOption(info)
	return (info.arg and Yikes.db.profile[info.arg] or Yikes.db.profile[info[#info]])
end

local function setOption(info, value)
	local key = info.arg or info[#info]
	Yikes.db.profile[key] = value
end

local function getMultiOption(info, name)
	return (info.arg and Yikes.db.profile[info.arg][name] or Yikes.db.profile[info[#info]][name])
end

local function setMultiOption(info, name, state)
	local key = info.arg or info[#info]
	if (state == nil) then
		if Yikes.db.profile[info.arg][name] ~= nil then
			state = false
		end
	end
	Yikes.db.profile[key][name] = state
end

local function getColorOption(info)
	local key = info.arg or info[#info]
	return Yikes.db.profile[key].r, Yikes.db.profile[key].g, Yikes.db.profile[key].b, Yikes.db.profile[key].a
end

local function setColorOption(info, r, g, b, a)
	local key = info.arg or info[#info]
	Yikes.db.profile[key].r, Yikes.db.profile[key].g, Yikes.db.profile[key].b, Yikes.db.profile[key].a = r, g, b, a
end

function Yikes:SetupOptions()
	self.options = {
		name = L["addon_name"],
		type = "group",
		childGroups = "tab",
		plugins = {},
		args = {
			general = {
				type="group",
				name=L["general_tab"],
				desc=L["general_tab"],
				order=1,
				childGroups="tab",
				args = {
					afkMessage = {
						type = "input",
						order = 5,
						name = L["afk_message"],
						desc = L["afk_message_desc"],
						width = "full",
						get = getOption,
						set = setOption,
					},
					backMessage = {
						type = "input",
						order = 10,
						name = L["back_message"],
						desc = L["back_message_desc"],
						width = "full",
						get = getOption,
						set = setOption,
					},
					alertPartyRaid = {
						type = "toggle",
						order = 20,
						name = L["alert_party_raid"],
						desc = L["alert_party_raid_desc"],
						width = "full",
						get = getOption,
						set = setOption,
					},
					mute = {
						type = "toggle",
						order = 30,
						name = L["mute"],
						desc = L["mute_desc"],
						get = getOption,
						set = setOption,
					},
				},
			},
			display = {
				type="group",
				name=L["display_tab"],
				desc=L["display_tab"],
				order=2,
				childGroups="tab",
				args = {
					channels = {
						type = "multiselect",
						order = 10,
						name = L["display_channels"],
						desc = L["display_channels_desc"],
						width = "full",
						values = {
							whisper = L["whisper"],
							party = L["party"],
							raid = L["raid"],
							guild = L["guild"],

						},
						get = getMultiOption,
						set = setMultiOption,
					},
					colourGroup = {
						type = "group",
						inline = true,
						name = L["colours"],
						order = 30,
						childGroups = "tab",
						args = {
							bgColour = {
								type = "color",
								order = 10,
								name = L["bg_colour"],
								desc = L["bg_colour_desc"],
								hasAlpha = true,
								get = getColorOption,
								set = setColorOption,
							},
							textColour = {
								type = "color",
								order = 20,
								name = L["text_colour"],
								desc = L["text_colour_desc"],
								hasAlpha = false,
								get = getColorOption,
								set = setColorOption,
							},
						},
					},
					font = {
						type = "select",
						name = L["font"],
						desc = L["font_desc"],
						order = 30,
						values = media:List('font'),
						get = function(info)
							local mt = media:List('font')
							for k,v in pairs(mt) do
								if v==self.db.profile.font then
									return k
								end
							end
						end,
						set = function(info,v)
							local mt = media:List('font')
							self.db.profile.font = mt[v]
						end,
						disabled = true,
						hidden = true,
					},
					fontSize = {
						type = "range",
						name = L["font_size"],
						desc = L["font_size_desc"],
						get = getOption,
						set = setOption,
						min = 8,
						max = 36,
						step = 1,
						order = 35,
						disabled = true,
						hidden = true,
					},
					fade = {
						type = "toggle",
						order = 40,
						width = "full",
						name = L["fade_messages"],
						desc = L["fade_messages_desc"],
						get = getOption,
						set = setOption,
					},
					fadeDuration = {
						type = "range",
						order = 50,
						width = "full",
						min = 0,
						max = 120,
						step = 1,
						bigStep = 5,
						name = L["fade_duration"],
						desc = L["fade_duration_desc"],
						get = getOption,
						set = setOption,
						disabled = function()
							return not self.db.profile.fade
						end,
					},
				},
			},
			about = {
				type = "group",
				name = L["about_tab"],
				desc = "About",
				order = 3,
				childGroups = "tab",
				args = {
					para1 = {
						type = "description",
						name = "Yikes v1.0 - 2008-04-16",
						order = 0,
					},
					para2 = {
						type = "description",
						name = "Written by Billi@Aszune.",
						order = 10,
					},
					para3 = {
						type = "description",
						name = "Thanks to:",
						order = 20,
					},
					para4 = {
						type = "description",
						name = "- NLR BossKey for the inspiration, and to the WowAce team for their libraries and code.",
						order = 21,
					},
					para5 = {
						type = "description",
						name = "- Stickleback for help testing.",
						order = 22,
					},
				},
			},
		}
	}

	self.options.plugins.profiles = { profiles = LibStub("AceDBOptions-3.0"):GetOptionsTable(self.db) }
	LibStub("AceConfig-3.0"):RegisterOptionsTable("Yikes", self.options)
	self.optionsFrame = LibStub("AceConfigDialog-3.0"):AddToBlizOptions("Yikes", "Yikes")
	self:RegisterChatCommand("yikes", "ChatCommand")

	self:Print(L["init_text"])

end
